Welcome to Pyrasite's documentation!
====================================

Pyrasite is a library and a set of tools for injecting code into running
Python programs.

:download: http://pypi.python.org/pypi/pyrasite
:source: http://github.com/lmacken/pyrasite
:mailing list: https://fedorahosted.org/mailman/listinfo/pyrasite
:jenkins: http://ci.csh.rit.edu/view/Pyrasite
:irc: #pyrasite on `Freenode <http://webchat.freenode.net>`_

Contents
---------

.. toctree::
   :maxdepth: 3

   Installing
   GUI
   CLI
   Payloads
   API
